/**
 * This file is part of the dcrypt project.
 *
 * Copyright: Copyright (C) dcrypt contributors 2008. All rights reserved.
 * License:   MIT
 * Authors:   Thomas Dixon
 */
 
 module dcrypt.crypto.BlockCipherPadding;
 
 public import dcrypt.crypto.errors.InvalidPaddingError;
 
 /** Base padding class for implementing block padding schemes. */
 abstract class BlockCipherPadding {
     /** Returns: The name of the padding scheme implemented. */
     char[] name();
     
     /**
      * Pad the (last) block of plaintext to block length.
      *
      * Params:
      *     input_ = Plaintext block to be padded.
      *     inOffset = Offset at which to begin padding input_.
      *
      * Returns: The number of padding bytes added.
      */ 
     uint padBlock(void[] input_, uint inOff);
     
     /**
      * Return the number of pad bytes in the block.
      *
      * Params:
      *     input_ = Padded block of which to count the pad bytes.
      *
      * Returns: The number of pad bytes in the block.
      *
      * Throws: dcrypt.crypto.errors.InvalidPaddingError if 
      *         pad length cannot be discerned.
      */
     uint padLength(void[] input_);
 }
